
# Type: transcript to gene relationship_subject




URI: [biolink:transcript_to_gene_relationship_subject](https://w3id.org/biolink/vocab/transcript_to_gene_relationship_subject)


## Domain and Range

[TranscriptToGeneRelationship](TranscriptToGeneRelationship.md) ->  <sub>REQ</sub> [Transcript](Transcript.md)

## Parents

 *  is_a: [sequence feature relationship➞subject](sequence_feature_relationship_subject.md)

## Children


## Used by

 * [TranscriptToGeneRelationship](TranscriptToGeneRelationship.md)
